AlertLocalization class

Constructors

AlertLocalization({String ok = "OK", String cancel = "Cancel", String loading = "Loading...", String error = "Error"})
const

Properties

cancel String
final
error String
final
hashCode int
The hash code for this object.
no setterinherited
loading String
final
ok String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaultLocalization AlertLocalization
getter/setter pair