AlertTheme class

Constructors

AlertTheme({Color? backgroundColor, TextStyle? titleStyle, TextStyle? descriptionStyle, ButtonStyle? buttonStyle, BorderRadius? borderRadius, List<BoxShadow>? shadow, Duration? animationDuration})
const

Properties

animationDuration Duration?
final
backgroundColor Color?
final
borderRadius BorderRadius?
final
buttonStyle ButtonStyle?
final
descriptionStyle TextStyle?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadow List<BoxShadow>?
final
titleStyle TextStyle?
final

Methods

copyWith({Color? backgroundColor, TextStyle? titleStyle, TextStyle? descriptionStyle, ButtonStyle? buttonStyle, BorderRadius? borderRadius, List<BoxShadow>? shadow, Duration? animationDuration}) AlertTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaultTheme AlertTheme
getter/setter pair