Responsive class

Constructors

Responsive(BuildContext context)

Properties

context BuildContext
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
no setter

Methods

hp(double percent) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wp(double percent) double

Operators

operator ==(Object other) bool
The equality operator.
inherited