AlertManager class

Constructors

AlertManager()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showAlert({required AlertType type, required String title, required String description, String? buttonText, VoidCallback? onPressed, AlertTheme? theme}) → void
showCustom({required Widget child, AlertTheme? theme}) → void
showLoading({String? message, Color? indicatorColor, AlertTheme? theme}) → void
showSelection({required AlertType type, required String title, required String description, required String leftText, required String rightText, VoidCallback? onLeft, VoidCallback? onRight, AlertTheme? theme}) → void
showToast({required AlertType type, required String message, Duration duration = const Duration(seconds: 2), AlertTheme? theme}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited