AlertConfig class
Constructors
- AlertConfig({required AlertType type, required String title, required String description, String? buttonText, VoidCallback? onPressed, AlertTheme? theme})
-
const
Properties
-
final
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onPressed → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → AlertTheme?
-
final
- title → String
-
final
- type → AlertType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited