SelectionConfig class

Constructors

SelectionConfig({required AlertType type, required String title, required String description, required String leftText, required String rightText, VoidCallback? onLeft, VoidCallback? onRight, AlertTheme? theme})
const

Properties

description String
final
hashCode int
The hash code for this object.
no setterinherited
leftText String
final
onLeft VoidCallback?
final
onRight VoidCallback?
final
rightText String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme AlertTheme?
final
title String
final
type AlertType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited